# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/domolibrary_extensions',
                'doc_host': 'https://jaewilson07.github.io',
                'git_url': 'https://github.com/jaewilson07/domolibrary_extensions',
                'lib_path': 'domolibrary_extensions'},
  'syms': { 'domolibrary_extensions.asana.auth': { 'domolibrary_extensions.asana.auth.AsanaAuth': ( 'asana/auth.html#asanaauth',
                                                                                                    'domolibrary_extensions/asana/auth.py'),
                                                   'domolibrary_extensions.asana.auth.AsanaAuth.__post_init__': ( 'asana/auth.html#asanaauth.__post_init__',
                                                                                                                  'domolibrary_extensions/asana/auth.py'),
                                                   'domolibrary_extensions.asana.auth.AsanaAuth.generate_auth_header': ( 'asana/auth.html#asanaauth.generate_auth_header',
                                                                                                                         'domolibrary_extensions/asana/auth.py'),
                                                   'domolibrary_extensions.asana.auth.AsanaAuth.get_auth_token': ( 'asana/auth.html#asanaauth.get_auth_token',
                                                                                                                   'domolibrary_extensions/asana/auth.py')},
            'domolibrary_extensions.asana.project': { 'domolibrary_extensions.asana.project.AsanaProject': ( 'asana/project.html#asanaproject',
                                                                                                             'domolibrary_extensions/asana/project.py'),
                                                      'domolibrary_extensions.asana.project.AsanaProject._from_json': ( 'asana/project.html#asanaproject._from_json',
                                                                                                                        'domolibrary_extensions/asana/project.py'),
                                                      'domolibrary_extensions.asana.project.AsanaProject.get_by_id': ( 'asana/project.html#asanaproject.get_by_id',
                                                                                                                       'domolibrary_extensions/asana/project.py'),
                                                      'domolibrary_extensions.asana.project.AsanaProject.get_projects': ( 'asana/project.html#asanaproject.get_projects',
                                                                                                                          'domolibrary_extensions/asana/project.py')},
            'domolibrary_extensions.asana.task': { 'domolibrary_extensions.asana.task.AsanaMembership': ( 'asana/task.html#asanamembership',
                                                                                                          'domolibrary_extensions/asana/task.py'),
                                                   'domolibrary_extensions.asana.task.AsanaMembership._from_json': ( 'asana/task.html#asanamembership._from_json',
                                                                                                                     'domolibrary_extensions/asana/task.py'),
                                                   'domolibrary_extensions.asana.task.AsanaMembership.to_text': ( 'asana/task.html#asanamembership.to_text',
                                                                                                                  'domolibrary_extensions/asana/task.py'),
                                                   'domolibrary_extensions.asana.task.AsanaSection': ( 'asana/task.html#asanasection',
                                                                                                       'domolibrary_extensions/asana/task.py'),
                                                   'domolibrary_extensions.asana.task.AsanaSection._from_json': ( 'asana/task.html#asanasection._from_json',
                                                                                                                  'domolibrary_extensions/asana/task.py'),
                                                   'domolibrary_extensions.asana.task.AsanaStory': ( 'asana/task.html#asanastory',
                                                                                                     'domolibrary_extensions/asana/task.py'),
                                                   'domolibrary_extensions.asana.task.AsanaStory._from_json': ( 'asana/task.html#asanastory._from_json',
                                                                                                                'domolibrary_extensions/asana/task.py'),
                                                   'domolibrary_extensions.asana.task.AsanaStory.to_text': ( 'asana/task.html#asanastory.to_text',
                                                                                                             'domolibrary_extensions/asana/task.py'),
                                                   'domolibrary_extensions.asana.task.AsanaTask': ( 'asana/task.html#asanatask',
                                                                                                    'domolibrary_extensions/asana/task.py'),
                                                   'domolibrary_extensions.asana.task.AsanaTask._from_json': ( 'asana/task.html#asanatask._from_json',
                                                                                                               'domolibrary_extensions/asana/task.py'),
                                                   'domolibrary_extensions.asana.task.AsanaTask.get_by_id': ( 'asana/task.html#asanatask.get_by_id',
                                                                                                              'domolibrary_extensions/asana/task.py'),
                                                   'domolibrary_extensions.asana.task.AsanaTask.get_stories': ( 'asana/task.html#asanatask.get_stories',
                                                                                                                'domolibrary_extensions/asana/task.py'),
                                                   'domolibrary_extensions.asana.task.AsanaTask.to_md': ( 'asana/task.html#asanatask.to_md',
                                                                                                          'domolibrary_extensions/asana/task.py'),
                                                   'domolibrary_extensions.asana.task.ap.AsanaProject.get_tasks': ( 'asana/task.html#ap.asanaproject.get_tasks',
                                                                                                                    'domolibrary_extensions/asana/task.py'),
                                                   'domolibrary_extensions.asana.task.handle_render_datetime': ( 'asana/task.html#handle_render_datetime',
                                                                                                                 'domolibrary_extensions/asana/task.py'),
                                                   'domolibrary_extensions.asana.task.handle_render_default': ( 'asana/task.html#handle_render_default',
                                                                                                                'domolibrary_extensions/asana/task.py'),
                                                   'domolibrary_extensions.asana.task.handle_render_membership': ( 'asana/task.html#handle_render_membership',
                                                                                                                   'domolibrary_extensions/asana/task.py'),
                                                   'domolibrary_extensions.asana.task.handle_render_stories': ( 'asana/task.html#handle_render_stories',
                                                                                                                'domolibrary_extensions/asana/task.py'),
                                                   'domolibrary_extensions.asana.task.handle_render_user': ( 'asana/task.html#handle_render_user',
                                                                                                             'domolibrary_extensions/asana/task.py'),
                                                   'domolibrary_extensions.asana.task.render_field': ( 'asana/task.html#render_field',
                                                                                                       'domolibrary_extensions/asana/task.py')},
            'domolibrary_extensions.asana.user': { 'domolibrary_extensions.asana.user.AsanaUser': ( 'asana/user.html#asanauser',
                                                                                                    'domolibrary_extensions/asana/user.py'),
                                                   'domolibrary_extensions.asana.user.AsanaUser._from_json': ( 'asana/user.html#asanauser._from_json',
                                                                                                               'domolibrary_extensions/asana/user.py'),
                                                   'domolibrary_extensions.asana.user.AsanaUser.get_by_id': ( 'asana/user.html#asanauser.get_by_id',
                                                                                                              'domolibrary_extensions/asana/user.py')},
            'domolibrary_extensions.client': { 'domolibrary_extensions.client.Auth': ( 'client/client.html#auth',
                                                                                       'domolibrary_extensions/client.py'),
                                               'domolibrary_extensions.client.Auth.generate_auth_header': ( 'client/client.html#auth.generate_auth_header',
                                                                                                            'domolibrary_extensions/client.py'),
                                               'domolibrary_extensions.client.BaseError': ( 'client/client.html#baseerror',
                                                                                            'domolibrary_extensions/client.py'),
                                               'domolibrary_extensions.client.BaseError.__init__': ( 'client/client.html#baseerror.__init__',
                                                                                                     'domolibrary_extensions/client.py'),
                                               'domolibrary_extensions.client.BaseError_Validation': ( 'client/client.html#baseerror_validation',
                                                                                                       'domolibrary_extensions/client.py'),
                                               'domolibrary_extensions.client.BaseError_Validation.__init__': ( 'client/client.html#baseerror_validation.__init__',
                                                                                                                'domolibrary_extensions/client.py'),
                                               'domolibrary_extensions.client.ResponseGetData': ( 'client/client.html#responsegetdata',
                                                                                                  'domolibrary_extensions/client.py'),
                                               'domolibrary_extensions.client.ResponseGetData.__post_init__': ( 'client/client.html#responsegetdata.__post_init__',
                                                                                                                'domolibrary_extensions/client.py'),
                                               'domolibrary_extensions.client.ResponseGetData._from_cache': ( 'client/client.html#responsegetdata._from_cache',
                                                                                                              'domolibrary_extensions/client.py'),
                                               'domolibrary_extensions.client.ResponseGetData._from_httpx': ( 'client/client.html#responsegetdata._from_httpx',
                                                                                                              'domolibrary_extensions/client.py'),
                                               'domolibrary_extensions.client.ResponseGetData._from_stream': ( 'client/client.html#responsegetdata._from_stream',
                                                                                                               'domolibrary_extensions/client.py'),
                                               'domolibrary_extensions.client._generate_cache_name': ( 'client/client.html#_generate_cache_name',
                                                                                                       'domolibrary_extensions/client.py'),
                                               'domolibrary_extensions.client.get_cache': ( 'client/client.html#get_cache',
                                                                                            'domolibrary_extensions/client.py'),
                                               'domolibrary_extensions.client.get_data': ( 'client/client.html#get_data',
                                                                                           'domolibrary_extensions/client.py'),
                                               'domolibrary_extensions.client.get_data_stream': ( 'client/client.html#get_data_stream',
                                                                                                  'domolibrary_extensions/client.py'),
                                               'domolibrary_extensions.client.looper': ( 'client/client.html#looper',
                                                                                         'domolibrary_extensions/client.py'),
                                               'domolibrary_extensions.client.prepare_fetch': ( 'client/client.html#prepare_fetch',
                                                                                                'domolibrary_extensions/client.py'),
                                               'domolibrary_extensions.client.update_cache': ( 'client/client.html#update_cache',
                                                                                               'domolibrary_extensions/client.py')},
            'domolibrary_extensions.google.GDoc_File': { 'domolibrary_extensions.google.GDoc_File.GDocFile_DownloadError': ( 'google/gdoc_file.html#gdocfile_downloaderror',
                                                                                                                             'domolibrary_extensions/google/GDoc_File.py'),
                                                         'domolibrary_extensions.google.GDoc_File.GDocFile_DownloadError.__init__': ( 'google/gdoc_file.html#gdocfile_downloaderror.__init__',
                                                                                                                                      'domolibrary_extensions/google/GDoc_File.py'),
                                                         'domolibrary_extensions.google.GDoc_File.GDoc_File': ( 'google/gdoc_file.html#gdoc_file',
                                                                                                                'domolibrary_extensions/google/GDoc_File.py'),
                                                         'domolibrary_extensions.google.GDoc_File.GDoc_File.__post_init__': ( 'google/gdoc_file.html#gdoc_file.__post_init__',
                                                                                                                              'domolibrary_extensions/google/GDoc_File.py'),
                                                         'domolibrary_extensions.google.GDoc_File.GDoc_File._from_json': ( 'google/gdoc_file.html#gdoc_file._from_json',
                                                                                                                           'domolibrary_extensions/google/GDoc_File.py'),
                                                         'domolibrary_extensions.google.GDoc_File.GDoc_File.download_file': ( 'google/gdoc_file.html#gdoc_file.download_file',
                                                                                                                              'domolibrary_extensions/google/GDoc_File.py'),
                                                         'domolibrary_extensions.google.GDoc_File.GDoc_File.get_content': ( 'google/gdoc_file.html#gdoc_file.get_content',
                                                                                                                            'domolibrary_extensions/google/GDoc_File.py'),
                                                         'domolibrary_extensions.google.GDoc_File.GDoc_File.get_from_id': ( 'google/gdoc_file.html#gdoc_file.get_from_id',
                                                                                                                            'domolibrary_extensions/google/GDoc_File.py'),
                                                         'domolibrary_extensions.google.GDoc_File.GoogleDrive_MimeType_Enum': ( 'google/gdoc_file.html#googledrive_mimetype_enum',
                                                                                                                                'domolibrary_extensions/google/GDoc_File.py')},
            'domolibrary_extensions.google.GDoc_Files': { 'domolibrary_extensions.google.GDoc_Files.GDoc_Files': ( 'google/gdoc_files.html#gdoc_files',
                                                                                                                   'domolibrary_extensions/google/GDoc_Files.py'),
                                                          'domolibrary_extensions.google.GDoc_Files.GDoc_Files.__post_init__': ( 'google/gdoc_files.html#gdoc_files.__post_init__',
                                                                                                                                 'domolibrary_extensions/google/GDoc_Files.py'),
                                                          'domolibrary_extensions.google.GDoc_Files.GDoc_Files._get_folder_contents': ( 'google/gdoc_files.html#gdoc_files._get_folder_contents',
                                                                                                                                        'domolibrary_extensions/google/GDoc_Files.py'),
                                                          'domolibrary_extensions.google.GDoc_Files.GDoc_Files.get_files': ( 'google/gdoc_files.html#gdoc_files.get_files',
                                                                                                                             'domolibrary_extensions/google/GDoc_Files.py')},
            'domolibrary_extensions.google.GSearch': { 'domolibrary_extensions.google.GSearch.GoogleSearch': ( 'google/gsearch.html#googlesearch',
                                                                                                               'domolibrary_extensions/google/GSearch.py'),
                                                       'domolibrary_extensions.google.GSearch.GoogleSearch.search': ( 'google/gsearch.html#googlesearch.search',
                                                                                                                      'domolibrary_extensions/google/GSearch.py'),
                                                       'domolibrary_extensions.google.GSearch.GoogleSearchAuth': ( 'google/gsearch.html#googlesearchauth',
                                                                                                                   'domolibrary_extensions/google/GSearch.py'),
                                                       'domolibrary_extensions.google.GSearch.GoogleSearchAuth.__post_init__': ( 'google/gsearch.html#googlesearchauth.__post_init__',
                                                                                                                                 'domolibrary_extensions/google/GSearch.py'),
                                                       'domolibrary_extensions.google.GSearch.GoogleSearchAuth.generate_auth_header': ( 'google/gsearch.html#googlesearchauth.generate_auth_header',
                                                                                                                                        'domolibrary_extensions/google/GSearch.py')},
            'domolibrary_extensions.google.auth': { 'domolibrary_extensions.google.auth.GoogleAuth': ( 'google/auth.html#googleauth',
                                                                                                       'domolibrary_extensions/google/auth.py'),
                                                    'domolibrary_extensions.google.auth.GoogleAuth._new_token_via_auth_flow': ( 'google/auth.html#googleauth._new_token_via_auth_flow',
                                                                                                                                'domolibrary_extensions/google/auth.py'),
                                                    'domolibrary_extensions.google.auth.GoogleAuth._refresh_token': ( 'google/auth.html#googleauth._refresh_token',
                                                                                                                      'domolibrary_extensions/google/auth.py'),
                                                    'domolibrary_extensions.google.auth.GoogleAuth.generate_service': ( 'google/auth.html#googleauth.generate_service',
                                                                                                                        'domolibrary_extensions/google/auth.py'),
                                                    'domolibrary_extensions.google.auth.GoogleAuth.get_creds_from_env': ( 'google/auth.html#googleauth.get_creds_from_env',
                                                                                                                          'domolibrary_extensions/google/auth.py'),
                                                    'domolibrary_extensions.google.auth.GoogleAuth.get_creds_from_file': ( 'google/auth.html#googleauth.get_creds_from_file',
                                                                                                                           'domolibrary_extensions/google/auth.py'),
                                                    'domolibrary_extensions.google.auth.GoogleAuth_NoEnv_Error': ( 'google/auth.html#googleauth_noenv_error',
                                                                                                                   'domolibrary_extensions/google/auth.py'),
                                                    'domolibrary_extensions.google.auth.GoogleAuth_NoEnv_Error.__init__': ( 'google/auth.html#googleauth_noenv_error.__init__',
                                                                                                                            'domolibrary_extensions/google/auth.py')},
            'domolibrary_extensions.integrations.ProxyCurl': { 'domolibrary_extensions.integrations.ProxyCurl.ProxyCurlAuth': ( 'integrations/proxycurl.html#proxycurlauth',
                                                                                                                                'domolibrary_extensions/integrations/ProxyCurl.py'),
                                                               'domolibrary_extensions.integrations.ProxyCurl.ProxyCurlAuth.generate_auth_header': ( 'integrations/proxycurl.html#proxycurlauth.generate_auth_header',
                                                                                                                                                     'domolibrary_extensions/integrations/ProxyCurl.py'),
                                                               'domolibrary_extensions.integrations.ProxyCurl.get_linked_in_profile_route': ( 'integrations/proxycurl.html#get_linked_in_profile_route',
                                                                                                                                              'domolibrary_extensions/integrations/ProxyCurl.py'),
                                                               'domolibrary_extensions.integrations.ProxyCurl.scrape_linkedin_profile': ( 'integrations/proxycurl.html#scrape_linkedin_profile',
                                                                                                                                          'domolibrary_extensions/integrations/ProxyCurl.py')},
            'domolibrary_extensions.jira.auth': { 'domolibrary_extensions.jira.auth.JiraAuth': ( 'jira/auth.html#jiraauth',
                                                                                                 'domolibrary_extensions/jira/auth.py'),
                                                  'domolibrary_extensions.jira.auth.JiraAuthPat': ( 'jira/auth.html#jiraauthpat',
                                                                                                    'domolibrary_extensions/jira/auth.py'),
                                                  'domolibrary_extensions.jira.auth.JiraAuthPat.__post_init__': ( 'jira/auth.html#jiraauthpat.__post_init__',
                                                                                                                  'domolibrary_extensions/jira/auth.py'),
                                                  'domolibrary_extensions.jira.auth.JiraAuthPat.generate_auth_header': ( 'jira/auth.html#jiraauthpat.generate_auth_header',
                                                                                                                         'domolibrary_extensions/jira/auth.py'),
                                                  'domolibrary_extensions.jira.auth.JiraAuthPat.who_am_i': ( 'jira/auth.html#jiraauthpat.who_am_i',
                                                                                                             'domolibrary_extensions/jira/auth.py'),
                                                  'domolibrary_extensions.jira.auth._JiraAuthPat_Required': ( 'jira/auth.html#_jiraauthpat_required',
                                                                                                              'domolibrary_extensions/jira/auth.py'),
                                                  'domolibrary_extensions.jira.auth._JiraAuth_Optional': ( 'jira/auth.html#_jiraauth_optional',
                                                                                                           'domolibrary_extensions/jira/auth.py'),
                                                  'domolibrary_extensions.jira.auth._JiraAuth_Required': ( 'jira/auth.html#_jiraauth_required',
                                                                                                           'domolibrary_extensions/jira/auth.py')},
            'domolibrary_extensions.jira.routes': { 'domolibrary_extensions.jira.routes.get_boards': ( 'jira/routes.html#get_boards',
                                                                                                       'domolibrary_extensions/jira/routes.py')},
            'domolibrary_extensions.utils': { 'domolibrary_extensions.utils.ImageBlockConverter': ( 'utils.html#imageblockconverter',
                                                                                                    'domolibrary_extensions/utils.py'),
                                              'domolibrary_extensions.utils.ImageBlockConverter.convert_img': ( 'utils.html#imageblockconverter.convert_img',
                                                                                                                'domolibrary_extensions/utils.py'),
                                              'domolibrary_extensions.utils.convert_html_to_markdown': ( 'utils.html#convert_html_to_markdown',
                                                                                                         'domolibrary_extensions/utils.py'),
                                              'domolibrary_extensions.utils.convert_str_file_name': ( 'utils.html#convert_str_file_name',
                                                                                                      'domolibrary_extensions/utils.py'),
                                              'domolibrary_extensions.utils.convert_str_keep_alphanumeric': ( 'utils.html#convert_str_keep_alphanumeric',
                                                                                                              'domolibrary_extensions/utils.py'),
                                              'domolibrary_extensions.utils.convert_str_remove_accents': ( 'utils.html#convert_str_remove_accents',
                                                                                                           'domolibrary_extensions/utils.py'),
                                              'domolibrary_extensions.utils.convert_str_to_date': ( 'utils.html#convert_str_to_date',
                                                                                                    'domolibrary_extensions/utils.py'),
                                              'domolibrary_extensions.utils.convert_str_to_snake_case': ( 'utils.html#convert_str_to_snake_case',
                                                                                                          'domolibrary_extensions/utils.py'),
                                              'domolibrary_extensions.utils.detect_encoding': ( 'utils.html#detect_encoding',
                                                                                                'domolibrary_extensions/utils.py'),
                                              'domolibrary_extensions.utils.download_pptx': ( 'utils.html#download_pptx',
                                                                                              'domolibrary_extensions/utils.py'),
                                              'domolibrary_extensions.utils.download_zip': ( 'utils.html#download_zip',
                                                                                             'domolibrary_extensions/utils.py'),
                                              'domolibrary_extensions.utils.export_env': ( 'utils.html#export_env',
                                                                                           'domolibrary_extensions/utils.py'),
                                              'domolibrary_extensions.utils.gather_with_concurrency': ( 'utils.html#gather_with_concurrency',
                                                                                                        'domolibrary_extensions/utils.py'),
                                              'domolibrary_extensions.utils.get_all_files_and_folders': ( 'utils.html#get_all_files_and_folders',
                                                                                                          'domolibrary_extensions/utils.py'),
                                              'domolibrary_extensions.utils.md': ('utils.html#md', 'domolibrary_extensions/utils.py'),
                                              'domolibrary_extensions.utils.read_html_file': ( 'utils.html#read_html_file',
                                                                                               'domolibrary_extensions/utils.py'),
                                              'domolibrary_extensions.utils.remove_query_params_from_url': ( 'utils.html#remove_query_params_from_url',
                                                                                                             'domolibrary_extensions/utils.py'),
                                              'domolibrary_extensions.utils.rename_filepath_to_match_datatype': ( 'utils.html#rename_filepath_to_match_datatype',
                                                                                                                  'domolibrary_extensions/utils.py'),
                                              'domolibrary_extensions.utils.update_env': ( 'utils.html#update_env',
                                                                                           'domolibrary_extensions/utils.py'),
                                              'domolibrary_extensions.utils.upsert_folder': ( 'utils.html#upsert_folder',
                                                                                              'domolibrary_extensions/utils.py')}}}



# AUTOGENERATED! DO NOT EDIT! File to edit: ../../nbs/jira/routes.ipynb.

# %% auto 0
__all__ = ['get_boards']

# %% ../../nbs/jira/routes.ipynb 2
import urllib.parse as parse
import httpx
from dataclasses import dataclass, field

import domolibrary_extensions.client as gd
import domolibrary_extensions.jira.auth as ja

# %% ../../nbs/jira/routes.ipynb 5
async def get_boards(
    auth: ja.JiraAuth,
    params: dict = None,
    debug_api: bool = False,
    debug_loop: bool = False,
    return_raw: bool = False,
    client: httpx.AsyncClient = None,
    is_ignore_cache: bool = False,
    cache_path: str = None,
):
    url = f"https://{auth.instance}/rest/agile/1.0/board"

    def arr_fn(res):
        return res.response["values"]

    client = client or httpx.AsyncClient()

    res = await gd.looper(
        url=url,
        auth=auth,
        arr_fn=arr_fn,
        params=params,
        method="GET",
        debug_loop=debug_loop,
        debug_api=debug_api,
        client=client,
        is_ignore_cache=is_ignore_cache,
        cache_path=cache_path,
    )

    if return_raw:
        return res

    return res.response



# AUTOGENERATED! DO NOT EDIT! File to edit: ../../nbs/google/GDoc_Files.ipynb.

# %% auto 0
__all__ = ['GDoc_Files']

# %% ../../nbs/google/GDoc_Files.ipynb 2
import os

from dataclasses import dataclass, field
from typing import List

from domolibrary_extensions.utils import convert_str_file_name
import domolibrary_extensions.google.auth as ga
import domolibrary_extensions.google.GDoc_File as gd

from nbdev.showdoc import patch_to

# %% ../../nbs/google/GDoc_Files.ipynb 5
@dataclass
class GDoc_Files:
    auth: ga.GoogleAuth = field(repr=False)

    folder_id: str = None
    folder_content: List[gd.GDoc_File] = field(default_factory=lambda: [])

    service: ga.Resource = field(default=None, repr=False)
    creds: ga.Credentials = field(default=None, repr=False)

    def __post_init__(self):
        self.creds = self.auth.creds
        self.service = self.auth.generate_service(
            service_name="drive", service_version="v3"
        )

# %% ../../nbs/google/GDoc_Files.ipynb 6
@patch_to(GDoc_Files)
def _get_folder_contents(
    self: GDoc_Files, folder_id: str, return_raw: bool = False
) -> List[gd.GDoc_File]:
    """
    retrieves dictionary representation of objects in google_drive folder
    if the folder_id maps to a file will return list with one object
    """
    auth = self.auth
    page_token = None
    file_ls = []

    while True:
        res = (
            auth.service.files()
            .list(
                q=f"'{folder_id}' in parents",
                pageSize=10,
                fields="nextPageToken, files(id,webViewLink, name, mimeType,modifiedTime )",
                pageToken=page_token,
            )
            .execute()
        )

        file_ls += res.get("files", [])

        page_token = res.get("nextPageToken", None)

        if not page_token:
            break

    if return_raw:
        return file_ls

    return [gd.GDoc_File._from_json(file_obj, auth=self.auth) for file_obj in file_ls]

# %% ../../nbs/google/GDoc_Files.ipynb 8
@patch_to(GDoc_Files)
def get_files(
    self: GDoc_Files, folder_id, file_ls=None, folder_path="", is_recursive: bool = True
):
    auth = self.auth

    if not file_ls:
        file_ls = []

    """recursive function to get files in a folder and map over files in subfolder"""

    new_files = self._get_folder_contents(folder_id=folder_id)

    file_ls += new_files

    if new_files and is_recursive:
        [
            self.get_files(
                folder_id=google_doc.doc_id,
                folder_path=os.path.join(
                    folder_path, convert_str_file_name(google_doc.doc_name)
                ),
                file_ls=file_ls,
            )
            for google_doc in new_files
            if google_doc.mime_type == "folder"
        ]

    self.file_ls = file_ls
    return self.file_ls



# AUTOGENERATED! DO NOT EDIT! File to edit: ../../nbs/integrations/proxycurl.ipynb.

# %% auto 0
__all__ = ['ProxyCurlAuth', 'get_linked_in_profile_route', 'scrape_linkedin_profile']

# %% ../../nbs/integrations/proxycurl.ipynb 3
from dataclasses import dataclass, field
import httpx
import domolibrary_extensions.client as gd
import inspect

# %% ../../nbs/integrations/proxycurl.ipynb 6
@dataclass
class ProxyCurlAuth(gd.Auth):
    """this library uses proxycurl to interact with LinkedIn APIs
    setup an account at https://proxycurl.com/
    """

    api_key: str = field(repr=False)  # key from proxycurl
    headers: dict = field(repr=False, default_factory=dict)

    def generate_auth_header(self):
        """interal method for generating a properly formatted proxycurl auth header"""
        return {"Authorization": f"Bearer {self.api_key}"}

# %% ../../nbs/integrations/proxycurl.ipynb 10
async def get_linked_in_profile_route(
    auth: ProxyCurlAuth,
    linkedin_profile_url: str = None,
    client: httpx.AsyncClient = None,
    cache_path: str = None,
    is_ignore_cache: bool = False,
    parent_class: str = None,
    debug_api: bool = False,
    debug_prn: bool = False,
):
    """gets a linkedin profiel via the proxycurl API"""

    url = "https://nubela.co/proxycurl/api/v2/linkedin"

    if not cache_path:
        url_id = url.replace("https://www.linkedin.com/in/", "")
        url_id = url_id.split("/")[0]
        cache_path = "CACHE\linkedin_profile_{url_id}.json"

    params = {
        "linkedin_profile_url": linkedin_profile_url,
        #     "twitter_profile_url": "https://twitter.com/johnrmarty/",
        #     "facebook_profile_url": "https://facebook.com/johnrmarty/",
        #     "extra": "include",
        #     "github_profile_id": "include",
        #     "facebook_profile_id": "include",
        #     "twitter_profile_id": "include",
        #     "personal_contact_number": "include",
        #     "personal_email": "include",
        #     "inferred_salary": "include",
        #     "skills": "include",
        #     "use_cache": "if-present",
        #     "fallback_to_cache": "on-error",
    }

    res = await gd.get_data(
        url=url,
        params=params,
        auth=auth,
        method="GET",
        client=client,
        cache_path=cache_path,
        is_ignore_cache=is_ignore_cache,
        parent_class=parent_class,
        debug_api=debug_api,
        debug_prn=debug_prn,
    )

    return res

# %% ../../nbs/integrations/proxycurl.ipynb 14
async def scrape_linkedin_profile(
    auth: ProxyCurlAuth,
    linkedin_profile_url: str = None,
    client: httpx.AsyncClient = None,
    cache_path: str = None,
    is_ignore_cache: bool = False,
    debug_api: bool = False,
    debug_prn: bool = False,
):
    """scrape information from LinkedIn profiles via proxy curl"""

    res = await get_linked_in_profile_route(
        auth=auth,
        linkedin_profile_url=linkedin_profile_url,
        client=client,
        cache_path=cache_path,
        is_ignore_cache=is_ignore_cache,
        debug_api=debug_api,
        debug_prn=debug_prn,
    )

    profile_obj = res.response

    profile_obj = {
        key: value
        for key, value in profile_obj.items()
        if value and key not in ["people_also_viewed", "certifications"]
    }

    if profile_obj.get("groups"):
        for group_obj in profile_obj["groups"]:
            group_obj.pop("profile_pic_url")

    return profile_obj
